ArcGIS Server Python Client
===========================

.. toctree::
   :maxdepth: 2


This library provides a client interface to the REST API on ArcGIS Server 10.2.x

Source code is available in `Bitbucket <https://bitbucket.org/databasin/python-ags/>`_.


Requirements
------------

* requests



Server Administration
=====================
.. automodule:: ags.admin.server
   :members:


Geoprocessing Tasks
===================
.. automodule:: ags.gp
   :members:


Properties
==========
.. automodule:: ags.base
   :members:

.. automodule:: ags.admin.services.base
   :members:

.. automodule:: ags.admin.services.mapserver
   :members:

.. automodule:: ags.admin.services.gp
   :members:

.. automodule:: ags.admin.uploads
   :members: